import { createMemo, createRenderEffect, sharedConfig, splitProps, untrack, createContext, useContext, mergeProps, createComponent, createSignal, Show } from 'solid-js';

const booleans = ["allowfullscreen", "async", "autofocus", "autoplay", "checked", "controls", "default", "disabled", "formnovalidate", "hidden", "indeterminate", "ismap", "loop", "multiple", "muted", "nomodule", "novalidate", "open", "playsinline", "readonly", "required", "reversed", "seamless", "selected"];
const Properties = /*#__PURE__*/new Set(["className", "value", "readOnly", "formNoValidate", "isMap", "noModule", "playsInline", ...booleans]);
const ChildProperties = /*#__PURE__*/new Set(["innerHTML", "textContent", "innerText", "children"]);
const Aliases = {
  className: "class",
  htmlFor: "for"
};
const PropAliases = {
  class: "className",
  formnovalidate: "formNoValidate",
  ismap: "isMap",
  nomodule: "noModule",
  playsinline: "playsInline",
  readonly: "readOnly"
};
const DelegatedEvents = /*#__PURE__*/new Set(["beforeinput", "click", "dblclick", "contextmenu", "focusin", "focusout", "input", "keydown", "keyup", "mousedown", "mousemove", "mouseout", "mouseover", "mouseup", "pointerdown", "pointermove", "pointerout", "pointerover", "pointerup", "touchend", "touchmove", "touchstart"]);
const SVGElements = /*#__PURE__*/new Set([
"altGlyph", "altGlyphDef", "altGlyphItem", "animate", "animateColor", "animateMotion", "animateTransform", "circle", "clipPath", "color-profile", "cursor", "defs", "desc", "ellipse", "feBlend", "feColorMatrix", "feComponentTransfer", "feComposite", "feConvolveMatrix", "feDiffuseLighting", "feDisplacementMap", "feDistantLight", "feFlood", "feFuncA", "feFuncB", "feFuncG", "feFuncR", "feGaussianBlur", "feImage", "feMerge", "feMergeNode", "feMorphology", "feOffset", "fePointLight", "feSpecularLighting", "feSpotLight", "feTile", "feTurbulence", "filter", "font", "font-face", "font-face-format", "font-face-name", "font-face-src", "font-face-uri", "foreignObject", "g", "glyph", "glyphRef", "hkern", "image", "line", "linearGradient", "marker", "mask", "metadata", "missing-glyph", "mpath", "path", "pattern", "polygon", "polyline", "radialGradient", "rect",
"set", "stop",
"svg", "switch", "symbol", "text", "textPath",
"tref", "tspan", "use", "view", "vkern"]);
const SVGNamespace = {
  xlink: "http://www.w3.org/1999/xlink",
  xml: "http://www.w3.org/XML/1998/namespace"
};

function memo(fn, equals) {
  return createMemo(fn, undefined, !equals ? {
    equals
  } : undefined);
}

function reconcileArrays(parentNode, a, b) {
  let bLength = b.length,
      aEnd = a.length,
      bEnd = bLength,
      aStart = 0,
      bStart = 0,
      after = a[aEnd - 1].nextSibling,
      map = null;
  while (aStart < aEnd || bStart < bEnd) {
    if (a[aStart] === b[bStart]) {
      aStart++;
      bStart++;
      continue;
    }
    while (a[aEnd - 1] === b[bEnd - 1]) {
      aEnd--;
      bEnd--;
    }
    if (aEnd === aStart) {
      const node = bEnd < bLength ? bStart ? b[bStart - 1].nextSibling : b[bEnd - bStart] : after;
      while (bStart < bEnd) parentNode.insertBefore(b[bStart++], node);
    } else if (bEnd === bStart) {
      while (aStart < aEnd) {
        if (!map || !map.has(a[aStart])) a[aStart].remove();
        aStart++;
      }
    } else if (a[aStart] === b[bEnd - 1] && b[bStart] === a[aEnd - 1]) {
      const node = a[--aEnd].nextSibling;
      parentNode.insertBefore(b[bStart++], a[aStart++].nextSibling);
      parentNode.insertBefore(b[--bEnd], node);
      a[aEnd] = b[bEnd];
    } else {
      if (!map) {
        map = new Map();
        let i = bStart;
        while (i < bEnd) map.set(b[i], i++);
      }
      const index = map.get(a[aStart]);
      if (index != null) {
        if (bStart < index && index < bEnd) {
          let i = aStart,
              sequence = 1,
              t;
          while (++i < aEnd && i < bEnd) {
            if ((t = map.get(a[i])) == null || t !== index + sequence) break;
            sequence++;
          }
          if (sequence > index - bStart) {
            const node = a[aStart];
            while (bStart < index) parentNode.insertBefore(b[bStart++], node);
          } else parentNode.replaceChild(b[bStart++], a[aStart++]);
        } else aStart++;
      } else a[aStart++].remove();
    }
  }
}

const $$EVENTS = "_$DX_DELEGATE";
function template(html, check, isSVG) {
  const t = document.createElement("template");
  t.innerHTML = html;
  let node = t.content.firstChild;
  if (isSVG) node = node.firstChild;
  return node;
}
function delegateEvents(eventNames, document = window.document) {
  const e = document[$$EVENTS] || (document[$$EVENTS] = new Set());
  for (let i = 0, l = eventNames.length; i < l; i++) {
    const name = eventNames[i];
    if (!e.has(name)) {
      e.add(name);
      document.addEventListener(name, eventHandler);
    }
  }
}
function setAttribute(node, name, value) {
  if (value == null) node.removeAttribute(name);else node.setAttribute(name, value);
}
function setAttributeNS(node, namespace, name, value) {
  if (value == null) node.removeAttributeNS(namespace, name);else node.setAttributeNS(namespace, name, value);
}
function className(node, value) {
  if (value == null) node.removeAttribute("class");else node.className = value;
}
function addEventListener(node, name, handler, delegate) {
  if (delegate) {
    if (Array.isArray(handler)) {
      node[`$$${name}`] = handler[0];
      node[`$$${name}Data`] = handler[1];
    } else node[`$$${name}`] = handler;
  } else if (Array.isArray(handler)) {
    const handlerFn = handler[0];
    node.addEventListener(name, handler[0] = e => handlerFn.call(node, handler[1], e));
  } else node.addEventListener(name, handler);
}
function classList(node, value, prev = {}) {
  const classKeys = Object.keys(value || {}),
        prevKeys = Object.keys(prev);
  let i, len;
  for (i = 0, len = prevKeys.length; i < len; i++) {
    const key = prevKeys[i];
    if (!key || key === "undefined" || value[key]) continue;
    toggleClassKey(node, key, false);
    delete prev[key];
  }
  for (i = 0, len = classKeys.length; i < len; i++) {
    const key = classKeys[i],
          classValue = !!value[key];
    if (!key || key === "undefined" || prev[key] === classValue || !classValue) continue;
    toggleClassKey(node, key, true);
    prev[key] = classValue;
  }
  return prev;
}
function style(node, value, prev = {}) {
  const nodeStyle = node.style;
  const prevString = typeof prev === "string";
  if (value == null && prevString || typeof value === "string") return nodeStyle.cssText = value;
  prevString && (nodeStyle.cssText = undefined, prev = {});
  value || (value = {});
  let v, s;
  for (s in prev) {
    value[s] == null && nodeStyle.removeProperty(s);
    delete prev[s];
  }
  for (s in value) {
    v = value[s];
    if (v !== prev[s]) {
      nodeStyle.setProperty(s, v);
      prev[s] = v;
    }
  }
  return prev;
}
function spread(node, accessor, isSVG, skipChildren) {
  if (typeof accessor === "function") {
    createRenderEffect(current => spreadExpression(node, accessor(), current, isSVG, skipChildren));
  } else spreadExpression(node, accessor, undefined, isSVG, skipChildren);
}
function insert(parent, accessor, marker, initial) {
  if (marker !== undefined && !initial) initial = [];
  if (typeof accessor !== "function") return insertExpression(parent, accessor, initial, marker);
  createRenderEffect(current => insertExpression(parent, accessor(), current, marker), initial);
}
function assign(node, props, isSVG, skipChildren, prevProps = {}, skipRef = false) {
  props || (props = {});
  for (const prop in prevProps) {
    if (!(prop in props)) {
      if (prop === "children") continue;
      assignProp(node, prop, null, prevProps[prop], isSVG, skipRef);
    }
  }
  for (const prop in props) {
    if (prop === "children") {
      if (!skipChildren) insertExpression(node, props.children);
      continue;
    }
    const value = props[prop];
    prevProps[prop] = assignProp(node, prop, value, prevProps[prop], isSVG, skipRef);
  }
}
function getNextElement(template) {
  let node, key;
  if (!sharedConfig.context || !(node = sharedConfig.registry.get(key = getHydrationKey()))) {
    return template.cloneNode(true);
  }
  if (sharedConfig.completed) sharedConfig.completed.add(node);
  sharedConfig.registry.delete(key);
  return node;
}
function toPropertyName(name) {
  return name.toLowerCase().replace(/-([a-z])/g, (_, w) => w.toUpperCase());
}
function toggleClassKey(node, key, value) {
  const classNames = key.trim().split(/\s+/);
  for (let i = 0, nameLen = classNames.length; i < nameLen; i++) node.classList.toggle(classNames[i], value);
}
function assignProp(node, prop, value, prev, isSVG, skipRef) {
  let isCE, isProp, isChildProp;
  if (prop === "style") return style(node, value, prev);
  if (prop === "classList") return classList(node, value, prev);
  if (value === prev) return prev;
  if (prop === "ref") {
    if (!skipRef) {
      value(node);
    }
  } else if (prop.slice(0, 3) === "on:") {
    const e = prop.slice(3);
    prev && node.removeEventListener(e, prev);
    value && node.addEventListener(e, value);
  } else if (prop.slice(0, 10) === "oncapture:") {
    const e = prop.slice(10);
    prev && node.removeEventListener(e, prev, true);
    value && node.addEventListener(e, value, true);
  } else if (prop.slice(0, 2) === "on") {
    const name = prop.slice(2).toLowerCase();
    const delegate = DelegatedEvents.has(name);
    if (!delegate && prev) {
      const h = Array.isArray(prev) ? prev[0] : prev;
      node.removeEventListener(name, h);
    }
    if (delegate || value) {
      addEventListener(node, name, value, delegate);
      delegate && delegateEvents([name]);
    }
  } else if ((isChildProp = ChildProperties.has(prop)) || !isSVG && (PropAliases[prop] || (isProp = Properties.has(prop))) || (isCE = node.nodeName.includes("-"))) {
    if (prop === "class" || prop === "className") className(node, value);else if (isCE && !isProp && !isChildProp) node[toPropertyName(prop)] = value;else node[PropAliases[prop] || prop] = value;
  } else {
    const ns = isSVG && prop.indexOf(":") > -1 && SVGNamespace[prop.split(":")[0]];
    if (ns) setAttributeNS(node, ns, prop, value);else setAttribute(node, Aliases[prop] || prop, value);
  }
  return value;
}
function eventHandler(e) {
  const key = `$$${e.type}`;
  let node = e.composedPath && e.composedPath()[0] || e.target;
  if (e.target !== node) {
    Object.defineProperty(e, "target", {
      configurable: true,
      value: node
    });
  }
  Object.defineProperty(e, "currentTarget", {
    configurable: true,
    get() {
      return node || document;
    }
  });
  if (sharedConfig.registry && !sharedConfig.done) {
    sharedConfig.done = true;
    document.querySelectorAll("[id^=pl-]").forEach(elem => elem.remove());
  }
  while (node !== null) {
    const handler = node[key];
    if (handler && !node.disabled) {
      const data = node[`${key}Data`];
      data !== undefined ? handler.call(node, data, e) : handler.call(node, e);
      if (e.cancelBubble) return;
    }
    node = node.host && node.host !== node && node.host instanceof Node ? node.host : node.parentNode;
  }
}
function spreadExpression(node, props, prevProps = {}, isSVG, skipChildren) {
  props || (props = {});
  if (!skipChildren && "children" in props) {
    createRenderEffect(() => prevProps.children = insertExpression(node, props.children, prevProps.children));
  }
  props.ref && props.ref(node);
  createRenderEffect(() => assign(node, props, isSVG, true, prevProps, true));
  return prevProps;
}
function insertExpression(parent, value, current, marker, unwrapArray) {
  if (sharedConfig.context && !current) current = [...parent.childNodes];
  while (typeof current === "function") current = current();
  if (value === current) return current;
  const t = typeof value,
        multi = marker !== undefined;
  parent = multi && current[0] && current[0].parentNode || parent;
  if (t === "string" || t === "number") {
    if (sharedConfig.context) return current;
    if (t === "number") value = value.toString();
    if (multi) {
      let node = current[0];
      if (node && node.nodeType === 3) {
        node.data = value;
      } else node = document.createTextNode(value);
      current = cleanChildren(parent, current, marker, node);
    } else {
      if (current !== "" && typeof current === "string") {
        current = parent.firstChild.data = value;
      } else current = parent.textContent = value;
    }
  } else if (value == null || t === "boolean") {
    if (sharedConfig.context) return current;
    current = cleanChildren(parent, current, marker);
  } else if (t === "function") {
    createRenderEffect(() => {
      let v = value();
      while (typeof v === "function") v = v();
      current = insertExpression(parent, v, current, marker);
    });
    return () => current;
  } else if (Array.isArray(value)) {
    const array = [];
    const currentArray = current && Array.isArray(current);
    if (normalizeIncomingArray(array, value, current, unwrapArray)) {
      createRenderEffect(() => current = insertExpression(parent, array, current, marker, true));
      return () => current;
    }
    if (sharedConfig.context) {
      if (!array.length) return current;
      for (let i = 0; i < array.length; i++) {
        if (array[i].parentNode) return current = array;
      }
    }
    if (array.length === 0) {
      current = cleanChildren(parent, current, marker);
      if (multi) return current;
    } else if (currentArray) {
      if (current.length === 0) {
        appendNodes(parent, array, marker);
      } else reconcileArrays(parent, current, array);
    } else {
      current && cleanChildren(parent);
      appendNodes(parent, array);
    }
    current = array;
  } else if (value instanceof Node) {
    if (sharedConfig.context && value.parentNode) return current = multi ? [value] : value;
    if (Array.isArray(current)) {
      if (multi) return current = cleanChildren(parent, current, marker, value);
      cleanChildren(parent, current, null, value);
    } else if (current == null || current === "" || !parent.firstChild) {
      parent.appendChild(value);
    } else parent.replaceChild(value, parent.firstChild);
    current = value;
  } else ;
  return current;
}
function normalizeIncomingArray(normalized, array, current, unwrap) {
  let dynamic = false;
  for (let i = 0, len = array.length; i < len; i++) {
    let item = array[i],
        prev = current && current[i];
    if (item instanceof Node) {
      normalized.push(item);
    } else if (item == null || item === true || item === false) ; else if (Array.isArray(item)) {
      dynamic = normalizeIncomingArray(normalized, item, prev) || dynamic;
    } else if ((typeof item) === "function") {
      if (unwrap) {
        while (typeof item === "function") item = item();
        dynamic = normalizeIncomingArray(normalized, Array.isArray(item) ? item : [item], prev) || dynamic;
      } else {
        normalized.push(item);
        dynamic = true;
      }
    } else {
      const value = String(item);
      if (prev && prev.nodeType === 3 && prev.data === value) {
        normalized.push(prev);
      } else normalized.push(document.createTextNode(value));
    }
  }
  return dynamic;
}
function appendNodes(parent, array, marker) {
  for (let i = 0, len = array.length; i < len; i++) parent.insertBefore(array[i], marker);
}
function cleanChildren(parent, current, marker, replacement) {
  if (marker === undefined) return parent.textContent = "";
  const node = replacement || document.createTextNode("");
  if (current.length) {
    let inserted = false;
    for (let i = current.length - 1; i >= 0; i--) {
      const el = current[i];
      if (node !== el) {
        const isParent = el.parentNode === parent;
        if (!inserted && !i) isParent ? parent.replaceChild(node, el) : parent.insertBefore(node, marker);else isParent && el.remove();
      } else inserted = true;
    }
  } else parent.insertBefore(node, marker);
  return [node];
}
function getHydrationKey() {
  const hydrate = sharedConfig.context;
  return `${hydrate.id}${hydrate.count++}`;
}
const SVG_NAMESPACE = "http://www.w3.org/2000/svg";
function createElement(tagName, isSVG = false) {
  return isSVG ? document.createElementNS(SVG_NAMESPACE, tagName) : document.createElement(tagName);
}
function Dynamic(props) {
  const [p, others] = splitProps(props, ["component"]);
  const cached = createMemo(() => p.component);
  return createMemo(() => {
    const component = cached();
    switch (typeof component) {
      case "function":
        return untrack(() => component(others));
      case "string":
        const isSvg = SVGElements.has(component);
        const el = sharedConfig.context ? getNextElement() : createElement(component, isSvg);
        spread(el, others, isSvg);
        return el;
    }
  });
}

let e={data:""},t=t=>"object"==typeof window?((t?t.querySelector("#_goober"):window._goober)||Object.assign((t||document.head).appendChild(document.createElement("style")),{innerHTML:" ",id:"_goober"})).firstChild:t||e,l=/(?:([\u0080-\uFFFF\w-%@]+) *:? *([^{;]+?);|([^;}{]*?) *{)|(}\s*)/g,a=/\/\*[^]*?\*\/|  +/g,n=/\n+/g,o=(e,t)=>{let r="",l="",a="";for(let n in e){let c=e[n];"@"==n[0]?"i"==n[1]?r=n+" "+c+";":l+="f"==n[1]?o(c,n):n+"{"+o(c,"k"==n[1]?"":t)+"}":"object"==typeof c?l+=o(c,t?t.replace(/([^,])+/g,e=>n.replace(/(^:.*)|([^,])+/g,t=>/&/.test(t)?t.replace(/&/g,e):e?e+" "+t:t)):n):null!=c&&(n=/^--/.test(n)?n:n.replace(/[A-Z]/g,"-$&").toLowerCase(),a+=o.p?o.p(n,c):n+":"+c+";");}return r+(t&&a?t+"{"+a+"}":a)+l},c={},s=e=>{if("object"==typeof e){let t="";for(let r in e)t+=r+s(e[r]);return t}return e},i=(e,t,r,i,p)=>{let u=s(e),d=c[u]||(c[u]=(e=>{let t=0,r=11;for(;t<e.length;)r=101*r+e.charCodeAt(t++)>>>0;return "go"+r})(u));if(!c[d]){let t=u!==e?e:(e=>{let t,r,o=[{}];for(;t=l.exec(e.replace(a,""));)t[4]?o.shift():t[3]?(r=t[3].replace(n," ").trim(),o.unshift(o[0][r]=o[0][r]||{})):o[0][t[1]]=t[2].replace(n," ").trim();return o[0]})(e);c[d]=o(p?{["@keyframes "+d]:t}:t,r?"":"."+d);}let f=r&&c.g?c.g:null;return r&&(c.g=c[d]),((e,t,r,l)=>{l?t.data=t.data.replace(l,e):-1===t.data.indexOf(e)&&(t.data=r?e+t.data:t.data+e);})(c[d],t,i,f),d},p=(e,t,r)=>e.reduce((e,l,a)=>{let n=t[a];if(n&&n.call){let e=n(r),t=e&&e.props&&e.props.className||/^go/.test(e)&&e;n=t?"."+t:e&&"object"==typeof e?e.props?"":o(e,""):!1===e?"":e;}return e+l+(null==n?"":n)},"");function u(e){let r=this||{},l=e.call?e(r.p):e;return i(l.unshift?l.raw?p(l,[].slice.call(arguments,1),r.p):l.reduce((e,t)=>Object.assign(e,t&&t.call?t(r.p):t),{}):l,t(r.target),r.g,r.o,r.k)}u.bind({g:1});let h=u.bind({k:1});

const ThemeContext = createContext();

function makeStyled(tag) {
  let _ctx = this || {};
  return (...args) => {
    const Styled = props => {
      const theme = useContext(ThemeContext);
      const withTheme = mergeProps(props, { theme });
      const clone = mergeProps(withTheme, {
        get class() {
          const pClass = withTheme.class,
            append = "class" in withTheme && /^go[0-9]+/.test(pClass);
          // Call `css` with the append flag and pass the props
          let className = u.apply(
            { target: _ctx.target, o: append, p: withTheme, g: _ctx.g },
            args
          );
          return [pClass, className].filter(Boolean).join(" ");
        }
      });
      const [local, newProps] = splitProps(clone, ["as", "theme"]);
      const htmlProps = newProps;
      const createTag = local.as || tag;
      let el;

      if (typeof createTag === "function") {
        el = createTag(htmlProps);
      } else {
        {
          if (_ctx.g == 1) {
            // When using Global Styles we don't want to hydrate the unused nodes
            el = document.createElement(createTag);
            spread(el, htmlProps);
          } else {
            el = Dynamic(mergeProps({ component: createTag }, htmlProps));
          }
        }
      }
      return el;
    };
    Styled.class = props => {
      return untrack(() => {
        return u.apply({ target: _ctx.target, p: props, g: _ctx.g }, args);
      });
    };

    return Styled;
  };
}

const styled = new Proxy(makeStyled, {
  get(target, tag) {
    return target(tag);
  }
});

const primaryColor = "#1890ff";
const blackColor = "rgba(0, 0, 0, 0.85)";
const whiteColor = "#fff";
const redColor = "#ff4d4f";

const _tmpl$$2 = /*#__PURE__*/template(`<svg fill="currentColor" stroke-width="0" xmlns="http://www.w3.org/2000/svg"></svg>`),
      _tmpl$2$1 = /*#__PURE__*/template(`<title></title>`);

function IconTemplate(iconSrc, props) {
  return (() => {
    const _el$ = _tmpl$$2.cloneNode(true);

    spread(_el$, () => iconSrc.a, true, true);

    spread(_el$, props, true, true);

    insert(_el$, (() => {
      const _c$ = memo(() => !!props.title, true);

      return () => _c$() && (() => {
        const _el$2 = _tmpl$2$1.cloneNode(true);

        insert(_el$2, () => props.title);

        return _el$2;
      })();
    })());

    createRenderEffect(_p$ => {
      const _v$ = iconSrc.a.stroke,
            _v$2 = { ...props.style,
        overflow: "visible",
        color: props.color
      },
            _v$3 = props.size || "1em",
            _v$4 = props.size || "1em",
            _v$5 = iconSrc.c;

      _v$ !== _p$._v$ && setAttribute(_el$, "stroke", _p$._v$ = _v$);
      _p$._v$2 = style(_el$, _v$2, _p$._v$2);
      _v$3 !== _p$._v$3 && setAttribute(_el$, "height", _p$._v$3 = _v$3);
      _v$4 !== _p$._v$4 && setAttribute(_el$, "width", _p$._v$4 = _v$4);
      _v$5 !== _p$._v$5 && (_el$.innerHTML = _p$._v$5 = _v$5);
      return _p$;
    }, {
      _v$: undefined,
      _v$2: undefined,
      _v$3: undefined,
      _v$4: undefined,
      _v$5: undefined
    });

    return _el$;
  })();
}

function CgSpinner (props) {
      return IconTemplate({
        a: {"fill":"none","viewBox":"0 0 24 24"},
        c: '<path fill="currentColor" fill-rule="evenodd" d="M12 19a7 7 0 100-14 7 7 0 000 14zm0 3c5.523 0 10-4.477 10-10S17.523 2 12 2 2 6.477 2 12s4.477 10 10 10z" clip-rule="evenodd" opacity=".2"/><path fill="currentColor" d="M2 12C2 6.477 6.477 2 12 2v3a7 7 0 00-7 7H2z"/>'
      }, props)
  }

const rotate = h`
  from {
        transform:rotate(0deg);
    }
    to {
        transform:rotate(360deg);
    }
`;

const sizeInNumbner$1 = {
  xs: 16,
  sm: 22,
  md: 30,
  lg: 38,
  xlg: 44
};
const StyledSpan$1 = styled("span")`
  svg {
    animation: ${rotate}
      ${props => {
  const {
    speed = "0.75s"
  } = props;
  return speed;
}}
      linear infinite;
  }
`;

const Spinner = props => {
  const {
    size = "md",
    color,
    thickness,
    ...restProps
  } = props;
  let sizeIsNumber = isNaN(Number(size)) ? undefined : size;
  return createComponent(StyledSpan$1, {
    "class": "spinner",

    get children() {
      return createComponent(CgSpinner, mergeProps({
        get size() {
          return sizeIsNumber || sizeInNumbner$1[size];
        },

        color: color,
        stroke: color,
        "stroke-width": thickness
      }, restProps));
    }

  });
};

const _tmpl$$1 = /*#__PURE__*/template(`<div class="inner"></div>`),
      _tmpl$2 = /*#__PURE__*/template(`<span class="icon"></span>`);
const StyledButton = styled("button")`
  ${props => {
  const {
    block
  } = props;

  switch (block) {
    case true:
      return `display: block;`;

    default:
      return `display: inline-block;`;
  }
}}
  text-align: center;
  background-image: none;
  border: 1px solid transparent;
  cursor: pointer;
  transition: all 0.3s cubic-bezier(0.645, 0.045, 0.355, 1);
  user-select: none;
  touch-action: manipulation;
  height: 32px;
  padding: 4px 15px;
  font-size: 14px;
  border-radius: 2px;
  color: ${blackColor};
  background: ${whiteColor};
  line-height: normal;
  font-weight: 400;
  ${props => {
  const {
    bodyType,
    danger
  } = props;

  switch (bodyType) {
    case "dashed":
      return `
        border-style: dashed;
        border-color: ${blackColor};
        `;

    case "primaryDashed":
    case "primary":
      if (danger) {
        return `color: ${whiteColor};
    border-color:  ${redColor};
    background: ${redColor};
    `;
      } else {
        return `    color: ${whiteColor};
    border-color: ${primaryColor};
    background: ${primaryColor};    

    `;
      }

    case "link":
      return `color: ${primaryColor};
    border-color: transparent;
    background: transparent;`;

    case "text":
      return `color:${blackColor};
    border-color: transparent;
    background: transparent;`;

    default:
      return `border-style: solid;`;
  }
}}

  ${props => {
  const {
    danger,
    bodyType
  } = props;

  if (danger && bodyType === "primary") {
    return `
      border-color:${redColor};
      color:${whiteColor};
      `;
  } else if (bodyType === "primaryDashed") {
    return `
      border-color:${whiteColor};
      border-style: dashed;
      color:${whiteColor};
      `;
  } else if (danger && (bodyType === "text" || bodyType === "link")) {
    return `
      border-color:transparent;
      color:${redColor};
      `;
  } else if (danger) {
    return `
      border-color:${bodyType !== "default" ? redColor : "transparent"} ;
      color:${redColor};
      `;
  }

  return "";
}}

${props => {
  const {
    shape
  } = props;

  switch (shape) {
    case "circle":
      return `border-radius: 50%;`;

    case "round":
      return `border-radius: 40px;`;

    default:
      return `border-radius: 2px;`;
  }
}}
  ${props => {
  const {
    disabled
  } = props;

  if (disabled) {
    return `opacity: 0.35;`;
  }
}}


${props => {
  const {
    size = "middle"
  } = props;

  switch (size) {
    case "xs":
      return `height: 24px;
    padding: 0px 7px;
    font-size: 12px;
   `;

    default:
    case "sm":
      return `
    height: 32px;
    padding: 4px 15px;
    font-size: 14px;
   `;

    case "md":
      return `    height: 40px;
    padding: 6.4px 15px;
    font-size: 16px;
`;

    case "lg":
      return `    height: 44px;
    padding: 7.4px 16px;
    font-size: 18px;
`;

    case "xlg":
      return `    height: 48px;
    padding: 8.4px 18px;
    font-size: 20px;
`;
  }
}}

svg {
    margin: auto;
    display: block;
  }
  .spinner {
    display: inline-block;
    vertical-align: middle;
  }
  .icon {
    display: inline-block;
    vertical-align: middle;
    margin: 0;
  }
  .inner {
    display: inline-block;
    vertical-align: middle;
    ${props => {
  const {
    iconPosition,
    loading
  } = props;
  let paddingLeft = "";

  if (loading) {
    paddingLeft = "padding-left:4px;";
  }

  switch (iconPosition) {
    case "postfix":
      return `${paddingLeft}padding-right:4px;`;

    case "prefix":
      return "padding-left:4px;";
  }
}}
  }
`;

const Button = props => {
  const {
    icon,
    children,
    bodyType = "default",
    size = "md",
    loadingType = "inline",
    // TODO
    loading = false,
    disabled,
    danger,
    iconPosition = "prefix",
    ...restProps
  } = props;
  const color = bodyType === "primary" ? whiteColor : danger ? redColor : blackColor;
  return createComponent(StyledButton, mergeProps({
    bodyType: bodyType,
    size: size,
    iconPosition: iconPosition,
    disabled: loading || disabled,
    loading: loading,
    danger: danger
  }, restProps, {
    get children() {
      return [memo(() => loading && createComponent(Spinner, {
        size: "sm",
        color: color
      })), memo(() => icon && iconPosition === "prefix" && (() => {
        const _el$2 = _tmpl$2.cloneNode(true);

        insert(_el$2, icon);

        return _el$2;
      })()), (() => {
        const _el$ = _tmpl$$1.cloneNode(true);

        insert(_el$, children);

        return _el$;
      })(), memo(() => icon && iconPosition === "postfix" && (() => {
        const _el$3 = _tmpl$2.cloneNode(true);

        insert(_el$3, icon);

        return _el$3;
      })())];
    }

  }));
};

function IoCloseOutline (props) {
      return IconTemplate({
        a: {"viewBox":"0 0 512 512"},
        c: '<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M368 368L144 144M368 144L144 368"/>'
      }, props)
  }

const _tmpl$ = /*#__PURE__*/template(`<span class="inner"></span>`);
var ColorEnum;

(function (ColorEnum) {
  ColorEnum["magenta"] = "magenta";
  ColorEnum["red"] = "red";
  ColorEnum["volcano"] = "volcano";
  ColorEnum["orange"] = "orange";
  ColorEnum["gold"] = "gold";
  ColorEnum["lime"] = "lime";
  ColorEnum["green"] = "green";
  ColorEnum["blue"] = "blue";
  ColorEnum["geekblue"] = "geekblue";
  ColorEnum["purple"] = "purple";
  ColorEnum["cyan"] = "cyan";
})(ColorEnum || (ColorEnum = {}));

const colorValues = {
  magenta: {
    color: "#c41d7f",
    background: "#fff0f6",
    borderColor: "#ffadd2"
  },
  red: {
    color: "#cf1322",
    background: "#fff1f0",
    borderColor: "#ffa39e"
  },
  volcano: {
    color: "#d4380d",
    background: "#fff2e8",
    borderColor: "#ffbb96"
  },
  orange: {
    color: "#d46b08",
    background: "#fff7e6",
    borderColor: "#ffd591"
  },
  gold: {
    color: "#d48806",
    background: "#fffbe6",
    borderColor: "#ffe58f"
  },
  lime: {
    color: "#7cb305",
    background: "#fcffe6",
    borderColor: "#eaff8f"
  },
  green: {
    color: "#389e0d",
    background: "#f6ffed",
    borderColor: "#b7eb8f"
  },
  cyan: {
    color: "#08979c",
    background: "#e6fffb",
    borderColor: "#87e8de"
  },
  blue: {
    color: "#096dd9",
    background: "#e6f7ff",
    borderColor: "#91d5ff"
  },
  geekblue: {
    color: "#1d39c4",
    background: "#f0f5ff",
    borderColor: "#adc6ff"
  },
  purple: {
    color: "#531dab",
    background: "#f9f0ff",
    borderColor: "#d3adf7"
  }
};
const sizeInNumbner = {
  xs: 14,
  sm: 16,
  md: 18,
  lg: 22,
  xlg: 28
};

const getColorItem = color => {
  if (color) {
    const colorValue = colorValues[color];

    if (colorValue) {
      return colorValue;
    }
  }

  return undefined;
};

const StyledSpan = styled("span")`
  box-sizing: border-box;

  margin: 0 8px 0 0;
  color: #000000d9;
  font-size: 14px;
  line-height: 1.5715;
  list-style: none;
  display: inline-flex;
  height: auto;
  padding: 0 7px;
  font-size: 12px;
  line-height: 20px;
  white-space: nowrap;
  background: #fafafa;
  border: 1px solid #d9d9d9;
  border-radius: 2px;
  opacity: 1;
  transition: all 0.3s;
  & > * {
    margin-top: auto;
    margin-bottom: auto;
  }

  ${props => {
  const colorValue = getColorItem(props.color);

  if (colorValue) {
    const {
      background,
      borderColor,
      color
    } = colorValue;
    return `
      color:${color};
    background: ${background};
    border-color: ${borderColor};
      `;
  }

  return;
}}
  ${props => {
  const {
    size = "middle"
  } = props;

  switch (size) {
    case "xs":
      return `height: 24px;
    padding: 0px 7px;
    font-size: 12px;
   `;

    default:
    case "sm":
      return `
    height: 32px;
    padding: 4px 15px;
    font-size: 14px;
   `;

    case "md":
      return `    height: 40px;
    padding: 6.4px 15px;
    font-size: 16px;
`;

    case "lg":
      return `    height: 44px;
    padding: 7.4px 16px;
    font-size: 18px;
`;

    case "xlg":
      return `    height: 48px;
    padding: 8.4px 18px;
    font-size: 20px;
`;
  }
}}

  .close {
    margin-left: 4px;
  }
`;

const Tag = props => {
  const {
    closable,
    onClose = () => {},
    icon,
    children,
    color,
    size = "md",
    ...restProps
  } = props;
  const [closed, setClose] = createSignal(false);

  const close = () => {
    setClose(true);
    onClose();
  };

  const colorValue = getColorItem(props.color);
  return createComponent(Show, {
    get when() {
      return !closed();
    },

    get children() {
      return createComponent(StyledSpan, mergeProps({
        size: size,
        color: color
      }, restProps, {
        get children() {
          return [icon && icon, " ", (() => {
            const _el$ = _tmpl$.cloneNode(true);

            insert(_el$, children);

            return _el$;
          })(), createComponent(IoCloseOutline, {
            get size() {
              return sizeInNumbner[size];
            },

            onclick: close,

            get color() {
              return colorValue?.color || props.color || "#000000";
            },

            "class": "close"
          })];
        }

      }));
    }

  });
};

export { Button, Spinner, Tag };
//# sourceMappingURL=uipress.es.js.map
